Usage
=====


For an interactive example that demonstrates the usage of papermill, click the Binder link
below:

.. image:: https://mybinder.org/badge.svg
   :target: https://mybinder.org/v2/gh/nteract/papermill/master?filepath=binder%2Fprocess_highlight_dates.ipynb
   :alt: launch binder

Using papermill
---------------

The general workflow when using papermill is **parameterizing** a notebook,
**executing** it, as well as **recording**, **displaying**, or **storing** the results.
In addition to operating on a single notebook, papermill also works on
a collection of notebooks.

.. toctree::
   :maxdepth: 2

   usage-parameterize
   usage-execute
   usage-recording
   usage-display
   usage-store
   usage-collection